leap_year: LeapYear

Description Usage Arguments Value Note Examples

View source: R/leap_year.R

Description

This package has on function that declares whether or not the year entered as an argument is a leap year.

Usage

1
leap_year(year)

Arguments

year

Enter one year between 1804 & 2400. This must be a vector of length 1.

Value

The function will return whether or not the year entered as an argument is a leap year.

Note

The package contains a vector of leap year titled 'leap_years' that the leap_year() function uses.

Examples

1
2
3
4
## Not run: 
leap_year(1992)

## End(Not run)

nheng91/LeapYear documentation built on May 25, 2019, 10:36 p.m.