Description Usage Arguments Value Note Examples
This package has on function that declares whether or not the year entered as an argument is a leap year.
1 | leap_year(year)
|
year |
Enter one year between 1804 & 2400. This must be a vector of length 1. |
The function will return whether or not the year entered as an argument is a leap year.
The package contains a vector of leap year titled 'leap_years' that the leap_year() function uses.
1 2 3 4 | ## Not run:
leap_year(1992)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.